#######
AgavePy
#######

.. image:: https://badge.fury.io/py/agavepy.svg
    :target: http://badge.fury.io/py/agavepy

.. image:: https://travis-ci.org/TACC/agavepy.svg?branch=develop
    :target: https://travis-ci.org/TACC/agavepy

.. image:: https://readthedocs.org/projects/agavepy/badge/?version=latest
    :target: https://readthedocs.org/projects/agavepy/?badge=latest

.. image:: https://img.shields.io/pypi/l/Django.svg
    :target: https://raw.githubusercontent.com/TACC/agavepy/master/LICENSE

AgavePy is an open source Python SDK that enables you to interact 
with TapisAPI_ services using functions in your Python scripts and REPL.

************
Installation
************

Install latest from PyPi_:

.. code-block:: console

    pip install agavepy

Install a specific version:

.. code-block:: console

    pip install agavepy==1.0.0

Install from source:

.. code-block:: console

    git clone https://github.com/TACC/agavepy
    cd agavepy
    python setup.py install

*****
Usage
*****

Please consult the AgavePy_ for comprehensive configuration and 
usage information. 

************
Contributing
************

    * `View and file issues <https://github.com/TACC/agavepy/issues/>`_
    * `Request access to TACC.cloud Slack <http://bit.ly/join-tapis>`_

.. Links

.. _Docker: https://docs.docker.com/installation/#installation
.. _Jupyter: https://jupyter.org/
.. _Oauth2: https://auth0.com/docs/protocols/oauth2
.. _PyPI: https://pypi.python.org/pypi
.. |AgavePy| replace:: AgavePy docs
.. _AgavePy: https://agavepy.readthedocs.io/en/latest/
.. |TapisCLI| replace:: Tapis CLI docs
.. _TapisCLI: https://tapis-cli.readthedocs.io/en/latest/
.. |TapisAPI| replace:: Tapis API docs
.. _TapisAPI: https://tacc-cloud.readthedocs.io/projects/agave/en/latest/
.. |AbacoAPI| replace:: Abaco API docs
.. _AbacoAPI: https://tacc-cloud.readthedocs.io/projects/abaco/en/latest/
.. |TUP| replace:: TACC User Portal
.. _TUP: https://portal.tacc.utexas.edu/account-request

